package nz.co.searchwellington.utils;

import java.util.Map;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.log4j.Logger;

import com.google.inject.Inject;

public class CachingHttpFetcher extends HttpFetcher {
	
	private final Logger log = Logger.getLogger(CachingHttpFetcher.class);
	
	private static final int DEFAULT_TTL = 3600;

	private MemcachedCache cache;
	
	@Inject
	public CachingHttpFetcher(MemcachedCache cache) {	
		this.cache = cache;
	}
	
	public String httpFetch(String url, String charEncoding, String userAgent, Map<String, String> cookies) {
		log.info("Looking for url '" + url + "' in cache");
		final String content = fetchFromCache(url);
		if (content != null) {
			log.info("Found content for url '" + url + "' in cache");
			return content;
		}
		
		log.info("Attempting to live fetch url: " + url);
		final String fetchedContent = super.fetchContentFromLive(url, charEncoding, userAgent, cookies);

		if (fetchedContent != null) {
			cache.put(makeKeyFor(url), DEFAULT_TTL, fetchedContent);
		}
		return fetchedContent;		
	}
		
    public String fetchFromCache(String url) {
    	log.debug("Looking in cache for url '" + url);
    	return (String) cache.get(makeKeyFor(url));    	
    }

	private String makeKeyFor(String url) {
		return "brownbagpages" + DigestUtils.md5Hex(url);
	}
    
}
