package nz.co.searchwellington.utils;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.util.Map;
import java.util.zip.GZIPInputStream;

import org.apache.http.Header;
import org.apache.http.HeaderElement;
import org.apache.http.HttpEntity;
import org.apache.http.HttpException;
import org.apache.http.HttpHost;
import org.apache.http.HttpRequest;
import org.apache.http.HttpRequestInterceptor;
import org.apache.http.HttpResponse;
import org.apache.http.HttpResponseInterceptor;
import org.apache.http.HttpStatus;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.conn.ClientConnectionManager;
import org.apache.http.conn.params.ConnRoutePNames;
import org.apache.http.entity.HttpEntityWrapper;
import org.apache.http.impl.client.AbstractHttpClient;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.params.HttpParams;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.EntityUtils;
import org.apache.log4j.Logger;

public class HttpFetcher {	// TODO migrate to common-http

	private final Logger log = Logger.getLogger(HttpFetcher.class);
	
	private static final String GZIP = "gzip";
	private static final String ACCEPT_ENCODING = "Accept-Encoding";
	private static final int HTTP_TIMEOUT = 15000;

	private HttpParams params;
	private ClientConnectionManager connectionManager;
	private HttpHost proxy = new HttpHost("127.0.0.1", 3128, "http");
	
	protected String fetchContentFromLive(String pageURL, String pageCharacterEncoding, String userAgent, Map<String, String> cookies) {
		log.info("Fetching: " + pageURL);
		try {
            final HttpGet get = new HttpGet(pageURL);
            
            if (userAgent != null) {
            	get.addHeader("User-Agent", userAgent); 
            	log.info("Set user agent to: " + userAgent);
            }
            
            if (cookies != null) {            	
            	for (String cookieName : cookies.keySet()) {
            		final String cookieLine = cookieName + "=" + cookies.get(cookieName);
                	get.addHeader("Cookie", cookieLine); 
            		log.info("Added cookie header: " + cookieLine);
            	}						            	
            }
            
            get.addHeader("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
            get.addHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
                        
        	final HttpResponse response = setupHttpClient().execute(get);
			final int statusCode = response.getStatusLine().getStatusCode();
			if (statusCode == HttpStatus.SC_OK) {
				return EntityUtils.toString(response.getEntity(), pageCharacterEncoding);
				
            } else {
            	log.warn("Error response code was: " +statusCode);
            }

		} catch (MalformedURLException e) {
			log.warn(e);
		} catch (IOException e) {
			log.warn(e);
		}
		return null;
	}

	
	private HttpClient setupHttpClient() {
	    HttpClient client = new DefaultHttpClient(connectionManager, params);
	    client.getParams().setParameter(ConnRoutePNames.DEFAULT_PROXY, proxy);

		((AbstractHttpClient) client).addRequestInterceptor(new HttpRequestInterceptor() {
					public void process(final HttpRequest request,
							final HttpContext context) throws HttpException,
							IOException {
						if (!request.containsHeader(ACCEPT_ENCODING)) {
							request.addHeader(ACCEPT_ENCODING, GZIP);
						}
					}
				});
		
		((AbstractHttpClient) client).addResponseInterceptor(new HttpResponseInterceptor() {
			public void process(final HttpResponse response, final HttpContext context) throws HttpException, IOException {
				HttpEntity entity = response.getEntity();
				Header ceheader = entity.getContentEncoding();
				if (ceheader != null) {
					HeaderElement[] codecs = ceheader.getElements();
					for (int i = 0; i < codecs.length; i++) {
						if (codecs[i].getName().equalsIgnoreCase(GZIP)) {
							response.setEntity(new GzipDecompressingEntity(response.getEntity()));
							return;
						}
					}
				}
			}
		});
		
		client.getParams().setParameter("http.socket.timeout", new Integer(HTTP_TIMEOUT));	// TODO Is there an apache http constant for this?
		client.getParams().setParameter("http.connection.timeout", new Integer(HTTP_TIMEOUT));
		return client;
	}

	private static class GzipDecompressingEntity extends HttpEntityWrapper {

		public GzipDecompressingEntity(final HttpEntity entity) {
			super(entity);
		}

		@Override
		public InputStream getContent() throws IOException, IllegalStateException {
			InputStream wrappedin = wrappedEntity.getContent();
			return new GZIPInputStream(wrappedin);
		}
		
		@Override
		public long getContentLength() {
			return this.wrappedEntity.getContentLength();
		}
	}

}
