package nz.co.searchwellington.utils;


import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/**
 * Provides methods for manipulating url strings.
 * 
 * @author tony
 *
 */
public class UrlFilters {

	/**
	 * Given a url string attempt to trim a trailing GET php session from the end.
	 * @param url
	 */
	public static String stripPhpSession(String url) {

		Logger.getLogger(UrlFilters.class).debug(
				"stripPhpSession processing: " + url);

		Pattern pattern;
		Matcher matcher;

		String REGEX = "&PHPSESSID=[0-9|a-f]{32}";
		pattern = Pattern.compile(REGEX);
		matcher = pattern.matcher(url);
		String result = matcher.replaceAll("");

		if (!result.equals(url)) {
			Logger.getLogger(UrlFilters.class).info(
					"stripPhpSession trimmed " + url + " to: " + result);
		}

		Logger.getLogger(UrlFilters.class).debug(
				"stripPhpSession result: " + result);
		return result;
	}

	/**
	 * 
	 */
	public static String stripNBSP(String content) {

		Pattern pattern;
		Matcher matcher;

		final String REGEX = "&nbsp;";
		pattern = Pattern.compile(REGEX);
		matcher = pattern.matcher(content);
		String result = matcher.replaceAll(" ");
		return result;
	}

	/**
	 * Trim leading and trailing white space off a string.
	 */
	public static String stripWhiteSpace(String title) {
		String result = title.trim();
		return result;
	}

	/**
	 * Check is all letters in a sentence are capitals.
	 * 
	 * @param input
	 * @return
	 */
	public static boolean isCapitalised(String input) {
		return (input.equals(StringUtils.upperCase(input)));
	}

	/**
	 * Given a sentence, check if it is entirely captalised. 
	 * If so lower case it, and captalise the first letter.
	 * ie. 
	 * THE QUICK BROWN FOX, becomes
	 * The quick brown fox.
	 * 
	 * @param input
	 * @return
	 */
	public static String lowerCappedSentence(String input) {

		String result = input;
		// Is the sentence entirely capitalised?
		if (isCapitalised(input)) {
			// Lower the string and then recapitalise.
			result = StringUtils.lowerCase(result);
			result = StringUtils.capitalize(result);
		}
		return result;
	}

	/**
	 * Given a URL string, strip the http:// prefix.
	 */
	public static String stripHttpPrefix(String url) {
		String REGEX = "^http://";
		Pattern pattern = Pattern.compile(REGEX);
		Matcher matcher = pattern.matcher(url);
		return matcher.replaceFirst("");
	}

    
    public static String stripLineBreaks(String url) {
        String REGEX = "\\s+";
        Pattern pattern = Pattern.compile(REGEX);
        Matcher matcher = pattern.matcher(url);
        return matcher.replaceAll(" ").trim();        
    }
    
    
	/**
	 * Given a URL to be past as click through to Technorati,
	 * strip the http:// prefix and url encode the remainer.
	 */
	public static String encodeForTechnoratiClickThrough(String url) {
		url = stripHttpPrefix(url);
		try {
            url = URLEncoder.encode(url, "UTF-8");
        } catch (UnsupportedEncodingException e) {
            Logger.getLogger(UrlFilters.class).error("Could not encode URL");
        }
		return url;
	}

    
	public static String stripHtmlTags(String html) {
        Pattern p = Pattern.compile("<.*?>");
        Matcher m = p.matcher(html);
        return m.replaceAll("");
    }
	

}