package nz.gen.wellington.screenscrapers;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import org.apache.log4j.Logger;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.PrototypicalNodeFactory;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public abstract class ScreenScraperImpl implements ScreenScraper {
    
	private static Logger log = Logger.getLogger(ScreenScraperImpl.class);
	
    private static final String DEFAULT_ENCODING = "ISO-8859-1";
    
    public String getCharacterEncoding() {
        return DEFAULT_ENCODING;
    }
    
    public Map<String, String> getCookies() {		
		return null;
	}
    
	public String getPageURL(String urlstub) {
		return this.getPageURL();
	}

	public String getUserAgent() {
		return null;
	}
	
	public String getName() {
		return "News items scraped from external website";
	}
	
	protected Date parseDate(String dateString, String dateFormat) {
        if (dateString != null) {
            Date date = null;
            // Parse this date.
            SimpleDateFormat sdfInput = new SimpleDateFormat(dateFormat);
            try {
                date = sdfInput.parse(dateString);
                return date;
            } catch (ParseException e) {
                log.warn("Invalid date input (" + dateString + ") for date format '" + dateFormat + "'");
                return null;
            }
            
        } else {
            log.warn("Expected date field was not seen on request");
            return null;
        }
    }
	
    protected String stripHtmlTags(String content) {
    	 content = content.replaceAll("<.*?>", "");    	 
         return content;
    }
    
    protected String stripHtmlComments(String content) {
        content = content.replace("<!--- -->", "");
        content = content.replace("-->", "");
        content = content.replace("<!--", "");
        return content;
    }
    
    protected NodeList extractTagsByName(String content, String name) throws ParserException {
		Parser parser = makeParser();
		parser.setInputHTML(content);
		NodeFilter tagNameFilter = new TagNameFilter(name);
		NodeList tagList = parser.extractAllNodesThatMatch(tagNameFilter);
		return tagList;
	}

    protected Tag extractTagByClassName(String content, String classname) throws ParserException {
        Parser parser = makeParser();
        parser.setInputHTML(content);
        NodeFilter classNameFilter = new HasAttributeFilter("class", classname);    
        NodeList tagList = parser.extractAllNodesThatMatch(classNameFilter);

        if (tagList.size() > 0) {
        	Tag tag = (Tag) tagList.elementAt(0);        
        	return tag;
        }
        return null;
    }
    
    protected NodeList extractTagsByNameAndClassName(String content, String tagName, String classname) throws ParserException {
    	Parser parser = makeParser();
		parser.setInputHTML(content);
		
		// TODO duplication		
		NodeFilter tagNameFilter = new TagNameFilter(tagName);
        NodeFilter classNameFilter = new HasAttributeFilter("class", classname);    

        NodeFilter[] filters = {tagNameFilter, classNameFilter};
        NodeFilter tagNameAndClassNameFilter = new AndFilter(filters);		
				
		NodeList tagList = parser.extractAllNodesThatMatch(tagNameAndClassNameFilter);
		return tagList;
	}
    
    protected NodeList extractTagsByClassName(String content, String classname) throws ParserException {
        Parser parser = makeParser();
        parser.setInputHTML(content);
        NodeFilter commentFilterNode = new HasAttributeFilter("class", classname);    
        NodeList tagList = parser.extractAllNodesThatMatch(commentFilterNode);      
        return tagList;
    }


    protected Tag extractTagsByWidth(String content, String width) throws ParserException {
        Parser parser = makeParser();
        parser.setInputHTML(content);
        NodeFilter commentFilterNode = new HasAttributeFilter("width", width);
        NodeList tagList = parser.extractAllNodesThatMatch(commentFilterNode);
        // TODO size check.
        Tag tag = (Tag) tagList.elementAt(0);        
        return tag;
    }
    
    protected Tag extractTagById(String content, String id) throws ParserException {
        Parser parser = makeParser();
        parser.setInputHTML(content);
        NodeFilter commentFilterNode = new HasAttributeFilter("id", id);    
        NodeList tagList = parser.extractAllNodesThatMatch(commentFilterNode);
        if (tagList.size() == 1) {
            Tag tag = (Tag) tagList.elementAt(0);        
            return tag;
        } 
        return null;
    }

	protected NodeList extractLinks(String content, String linkRegex) throws ParserException {
		Parser parser = makeParser();
        parser.setInputHTML(content);
		NodeFilter filterNode = new LinkRegexFilter(linkRegex);
		NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
		NodeList list = parser.extractAllNodesThatMatch(filter);
		return list;
	}
	
    @Deprecated
	protected NodeList extractNewsLinks(Parser parser, String linkRegex) throws ParserException {
		// Find links to newsDDD.html
		NodeFilter filterNode = new LinkRegexFilter(linkRegex);
		NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(
				Tag.class));
		NodeList list = parser.extractAllNodesThatMatch(filter);
		return list;
	}
    
	private Parser makeParser() {
		final Parser parser = new Parser();
		PrototypicalNodeFactory prototypicalNodeFactory = new PrototypicalNodeFactory();
		prototypicalNodeFactory.registerTag(new TimeTag());
		parser.setNodeFactory(prototypicalNodeFactory);			
		return parser;
	}
	
}
