package nz.gen.wellington.screenscrapers.auckland;


import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import nz.co.searchwellington.utils.UrlFilters;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.nodes.TextNode;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;



/**
 * Parses Auckland Regional Transports latest news page for news items.su
 * 
 * @author tony
 *
 */
public class ArcNewsScraper extends ScreenScraperImpl {

	
	Logger log = Logger.getLogger(ArcNewsScraper.class);
    final String ARC_LATEST_NEWS_URL = "http://www.arc.govt.nz/index.cfm?BBBFB157-2A38-4F87-BDB6-A696E36D1EA1";
	final String ARC_PREFIX = "http://www.arc.govt.nz/";
	final String ARC_DATE_FORMAT = "dd MMM yyyy";
	
	

	public String getPageURL() {
		 return ARC_LATEST_NEWS_URL;
	}
	
	

	public List parseContent(String content) {
		
		List newsitems = new ArrayList();
		
		try {
			Parser parser = new Parser();
			parser.setInputHTML(content);
						
			// Find the <h2>Latest media releases</h2> tag.
			final String NEWS_HEADING = "Latest media releases";	
						
			NodeFilter newsHeadingNodeFilter = new NodeClassFilter(TextNode.class);		
			NodeList list = parser.extractAllNodesThatMatch(newsHeadingNodeFilter);	
	
			// Foreach table row, attempt to extract the interesting bits.					
			for (int i = 0; i < list.size(); i++) {
				
				Node tag = (Node) list.elementAt(i);
				
				if (NEWS_HEADING.equals(tag.getText())) {
			
					// Find the table cell this heading is in.
					// All hrefs in this cell are to news items.
					Node newsCell = tag.getParent().getParent();				
					HasAttributeFilter linksFilter = new HasAttributeFilter("href");

					Parser rowParser = new Parser();	
					rowParser.setInputHTML(newsCell.toHtml());
					NodeList links_list = rowParser.extractAllNodesThatMatch(linksFilter);				
								
					if (links_list.size() > 0) {
												
						for (int j = 0; j < links_list.size(); j++) {
							Tag link_tag = (Tag) links_list.elementAt(j);
							
							Newsitem newsitem = extractNewsitemFromTag(link_tag);
									
							final boolean newsitemTitleIsOK = newsitem.getTitle() != null;
							final boolean newsitemUrlIsOK = newsitem.getUrl() != null;
							final boolean newsitemDescriptionIsOK = newsitem.getDescription() != null;
							final boolean newsitemDateIsOK = newsitem.getDate() != null;
							if (newsitemTitleIsOK && newsitemUrlIsOK && newsitemDescriptionIsOK && newsitemDateIsOK) { 
								newsitems.add(newsitem);			
							} else {
								log.warn("Newsitem is missing some fields; dropping.");
							}
											
						}				
						
					}
				}
			}
			
		} catch (ParserException e) {
			log.error("ParserException: " + e.getMessage());
		}
		
		return newsitems;
	}



	/**
	 * Given the a href tag to a newsitems, attempt to extract the newsitem.
	 * 
	 * @param link_tag
	 * @return
	 */
	private Newsitem extractNewsitemFromTag(Tag link_tag) {
		String url = null;
		String title = null;
		String description = null;
		String dateString = null;
		Date date = null;
		if (link_tag.getAttribute("href") != null) {
			url = ARC_PREFIX + link_tag.getAttribute("href");
			title = link_tag.toPlainTextString();							
			description = UrlFilters.stripWhiteSpace(link_tag.getNextSibling().getNextSibling().toHtml());
			
			dateString = link_tag.getPreviousSibling().getPreviousSibling().getPreviousSibling().getPreviousSibling().toHtml();
			if (dateString != null) {
				SimpleDateFormat sdfInput = new SimpleDateFormat(ARC_DATE_FORMAT);
				try {
					date = sdfInput.parse(dateString);									
				} catch (ParseException e) {
					log.error("Invalid date input; defaulting to null.");
				}
			} else {
				log.error("Could not find date string.");
			}
		}
		Newsitem newsitem = new NewsitemImpl();
		newsitem.setTitle(title);
		newsitem.setUrl(url);
		newsitem.setDescription(description);
		newsitem.setDate(date);
		return newsitem;
	}
	
	
}