package nz.gen.wellington.screenscrapers.auckland;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasChildFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.nodes.TextNode;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;



public class ArtaScraper extends ScreenScraperImpl {

	Logger log = Logger.getLogger(ArtaScraper.class);
    
    final String ARU_LATEST_NEWS_URL = "http://www.arta.co.nz/xxarta/news/index.cfm";
	
	final int MAX_ITEMS = 10;
	
	public String getPageURL() {
		return ARU_LATEST_NEWS_URL;
	}
	
	
	
	   public List <Newsitem> parseContent(String content) {

		List <Newsitem> newsitems = new ArrayList<Newsitem>();

		try {
			Parser parser = new Parser();
			parser.setInputHTML(content);

			// Obtain all of the table rows containing links to news items.
			NodeList list = extractNewsLinkTags(parser);

			// Foreach table row, attempt to extract the interesting bits.
			Parser rowParser = new Parser();
			
			int number_of_items  = list.size();
			if (number_of_items > MAX_ITEMS) {
				number_of_items = MAX_ITEMS;
			}
			
			for (int i = 0; i < number_of_items; i++) {
				Tag tag = (Tag) list.elementAt(i);
                
                

                Newsitem newsitem = new NewsitemImpl();

				String title = null;
				String url = null;
				String description = null;
				String date_string = null;
				Date date = null;

				// Look for the title and description in TextNodes
                NodeClassFilter description_filter = new NodeClassFilter(TextNode.class);
                rowParser.setInputHTML(tag.toHtml());
                NodeList description_list = rowParser.extractAllNodesThatMatch(description_filter);

                // There should be 8 of them.
                if (description_list.size() == 8) {
                    title = ((Node) description_list.elementAt(4)).getText();
                    description = ((Node) description_list.elementAt(6)).getText();
                    date_string = ((Node) description_list.elementAt(1)).getText();
                }

				if (date_string != null) {

					// Parse this date.
					SimpleDateFormat sdfInput = new SimpleDateFormat(
							"dd MMM yyyy");
					try {
						date = sdfInput.parse(date_string);
					} catch (ParseException e) {
						// Invalid date input.
						log.error("Invalid date input; defaulting to null.");
					}

				} else {
					log.error("Expected date field was not seen on request");
				}

				// Look for the href tag
				NodeFilter url_filter = new LinkRegexFilter(
						"http://www.arta.co.nz/xxarta/news/media_releasexx.cfm.*",
						true);
				rowParser.setInputHTML(tag.toHtml());
				NodeList url_list = rowParser
						.extractAllNodesThatMatch(url_filter);

				if (url_list.size() > 0) {
					Tag link_tag = (Tag) url_list.elementAt(0);
					url = link_tag.getAttribute("href");

				}

				newsitem.setTitle(title);
				newsitem.setDate(date);
				newsitem.setUrl(url);
				newsitem.setDescription(description);

                newsitem.flattenLoudCaps();
                
				newsitems.add(newsitem);

			}
		} catch (ParserException e) {
			// TODO handle html parsing exception.
		}

		return newsitems;
	}



    private NodeList extractNewsLinkTags(Parser parser) throws ParserException {
        NodeFilter filterNode = new AndFilter(
        		new TagNameFilter("TR"),
        		new HasChildFilter(
        				new AndFilter(
        						new TagNameFilter("TD"),
        						new HasChildFilter(
        								new LinkRegexFilter(
        										"http://www.arta.co.nz/xxarta/news/media_releasexx.cfm.*",
        										true)))));

        NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
        NodeList list = parser.extractAllNodesThatMatch(filter);
        return list;
    }

	
	

}
