package nz.gen.wellington.screenscrapers.auckland;


import java.util.ArrayList;
import java.util.List;

import nz.co.searchwellington.utils.UrlFilters;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.HasChildFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;



/**
 * Parses Auckland Regional Transports latest news page for news items.
 * 
 * @author tony
 *
 */
public class AruNewsScraper extends ScreenScraperImpl {

	
	Logger log = Logger.getLogger(AruNewsScraper.class);
    final String ARU_LATEST_NEWS_URL = "http://www.aucklandrugby.co.nz/club/news/index.html";
	final String ARU_PREFIX = "http://www.aucklandrugby.co.nz";
	  
	
	public String getPageURL() {
		 return ARU_LATEST_NEWS_URL;
	}
	
	


	public List <Newsitem> parseContent(String content) {
		
		List <Newsitem> newsitems = new ArrayList <Newsitem> ();
		
		try {
			Parser parser = new Parser();
			parser.setInputHTML(content);
						
			// Obtain all of the table rows containing links to news items.	
			NodeFilter filterNode = new AndFilter(new TagNameFilter("TR"),
					new HasChildFilter(new AndFilter(new TagNameFilter("TD"),
							new HasChildFilter(new TagNameFilter("DIV")))));
			
			NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
			NodeList list = parser.extractAllNodesThatMatch(filter);

	
			// Foreach table row, attempt to extract the interesting bits.
			Parser rowParser = new Parser();
			for (int i = 0; i < list.size(); i++) {
				Tag tag = (Tag) list.elementAt(i);
				
				String title = null;
				String url = null;
				String description = null;
		
				
			
						
				
				// Look for the href tag
				NodeFilter url_filter = new AndFilter (new LinkRegexFilter("/club/news/article.html.*", true),
										new HasAttributeFilter("class", "newsLink")
						);
				rowParser.setInputHTML(tag.toHtml());
				NodeList url_list = rowParser.extractAllNodesThatMatch(url_filter);				
				
				if (url_list.size() > 0) {
					Tag link_tag = (Tag) url_list.elementAt(0);
					if (link_tag.getAttribute("href") != null) {
						url = ARU_PREFIX + link_tag.getAttribute("href");
					}
					
					// Trim white space from title.
					title = UrlFilters.stripWhiteSpace(link_tag.toPlainTextString());
					title = StringEscapeUtils.unescapeHtml(title);
					
					description = link_tag.getParent().getNextSibling().toPlainTextString();
				}
				
				Newsitem newsitem = new NewsitemImpl();
				newsitem.setTitle(title);
				newsitem.setUrl(url);
				newsitem.setDescription(description);

				newsitems.add(newsitem);			
			}
		} catch (ParserException e) {
			log.error("ParserException: " + e.getMessage());
		}
		
		return newsitems;
	}
	
	
}