package nz.gen.wellington.screenscrapers.auckland;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;

import com.sun.syndication.feed.synd.SyndContent;
import com.sun.syndication.feed.synd.SyndEntry;
import com.sun.syndication.feed.synd.SyndFeed;
import com.sun.syndication.io.FeedException;
import com.sun.syndication.io.SyndFeedInput;
import com.sun.syndication.io.XmlReader;

/**
 * Auckland City Council provide a good news feed but the publication 
 * dates are in a NZGLS tag rather than in the expected place.
 * Can extract them from the link urls and repackage.
 * It would be nicer to write a custom Rome module for NZGLS though - life is short.
 * 
 * Sometimes includes links to test.akcity. Need to change these to www.akcity on the way through.
 */
public class AucklandCityCouncilScraper extends ScreenScraperImpl implements ScreenScraper {
    

    Logger log = Logger.getLogger(AucklandCityCouncilScraper.class);
    
    
	public String getPageURL() {
		return "http://www.aucklandcity.govt.nz/news/rssnews.xml";
	}

    
	public List<Newsitem> parseContent(String content) {
        List<Newsitem> newsItems = new ArrayList<Newsitem>();
        ByteArrayInputStream bs = new ByteArrayInputStream(content.getBytes());
        SyndFeedInput input = new SyndFeedInput();
        try {
            SyndFeed feed = input.build(new XmlReader(bs));

            for (int i = 0; i < feed.getEntries().size(); i++) {
                SyndEntry entry = (SyndEntry) feed.getEntries().get(i);
                Newsitem newsitem = new NewsitemImpl();
                newsitem.setTitle(entry.getTitle().trim());
                newsitem.setUrl(stripTestUrls(entry.getUri()));
                newsitem.setDescription(extractDescriptionFromFeedEntry(entry));

                Date date = extractDateFromUrl(entry.getUri());
                if (date != null) {
                    newsitem.setDate(date);
                }
                newsItems.add(newsitem);

            }

        } catch (IllegalArgumentException e) {
            log.error(e);
        } catch (FeedException e) {
            log.error(e);
        } catch (IOException e) {
            log.error(e);
        }

        return newsItems;
    }

    private String stripTestUrls(String uri) {
        return uri.replace("http://test", "http://www");
    }


    private Date extractDateFromUrl(String uri) {
        final String REGEX = "\\d\\d\\d\\d\\d\\d\\d\\d";

        Pattern p = Pattern.compile(REGEX);
        Matcher m = p.matcher(uri);

        if (m.find()) {
            String dateString = m.group(0);
            return parseDate(dateString, "yyyyMMdd");
        } else {
            log.warn("Could not find a date in the url: " + uri);
        }
        return null;
    }

    private String extractDescriptionFromFeedEntry(SyndEntry entry) {
        SyndContent descriptionContent = (SyndContent) entry.getDescription();
        return descriptionContent.getValue().trim();
    }

}
