package nz.gen.wellington.screenscrapers.auckland;

import java.util.ArrayList;
import java.util.List;

import nz.co.searchwellington.utils.UrlFilters;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.util.NodeList;


/**
 * Parses the Auckland District Health Board media release page for newsitems.
 * 
 * @author tony
 *
 */
public class AucklandHealthBoardScraper extends ScreenScraperImpl {

    private static final String ADBH_LATEST_NEWS = "http://www.adhb.govt.nz/news/media-releases.htm";
    private static final String ADHB_DATE_FORMAT = "dd MMMM yyyy";
    private static final String ADHB_PREFIX = "http://www.adhb.govt.nz/news/";
    
    
    Logger log = Logger.getLogger(AucklandHealthBoardScraper.class);
    
    
    public String getPageURL() {
        return ADBH_LATEST_NEWS;
    }

    
    public List parseContent(String content) {
        List newsItems = new ArrayList();

        Parser parser = new Parser();
        try {
            parser.setInputHTML(content);
            NodeFilter filterNode = new LinkRegexFilter("media-releases/*");
            NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
            NodeList list = parser.extractAllNodesThatMatch(filter);

            for (int i = 0; i < list.size(); i++) {
                Newsitem newsitem = new NewsitemImpl();

                Tag tag = (Tag) list.elementAt(i);

                String url = ADHB_PREFIX + tag.getAttribute("href");
                newsitem.setUrl(url);

                String dateString = UrlFilters.stripLineBreaks(tag.toPlainTextString());
                newsitem.setDate(parseDate(dateString, ADHB_DATE_FORMAT));

                Node contentTR = tag.getParent().getParent();
                Node titleNode = contentTR.getFirstChild().getNextSibling().getNextSibling().getNextSibling().getNextSibling().getNextSibling();

                newsitem.setTitle(UrlFilters.stripLineBreaks(titleNode.toPlainTextString()));
                newsItems.add(newsitem);
            }
            
        } catch (Exception e) {
            log.error(e.getMessage());
        }

        return newsItems;
    }

}
