package nz.gen.wellington.screenscrapers.auckland;


import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;


/**
 * Parses Auckland Universities press releases page for news items.
 * 
 * @author tony
 *
 */
public class AucklandUniversityScreenScraper extends ScreenScraperImpl {

	
	Logger log = Logger.getLogger(AucklandUniversityScreenScraper.class);
	// TODO 
    final String AU_LATEST_NEWS_URL = "http://www.auckland.ac.nz/uoa/about/news/";
	final String AU_PREFIX = "http://www.auckland.ac.nz";
	final String AUCKLAND_UNIVERSITY_DATE_FORMAT = "dd MMM yyyy";
	
	final int MAX_ITEMS = 10;
	

	public String getPageURL() {
		 return AU_LATEST_NEWS_URL;
	}
	
	

	public List <Newsitem> parseContent(String content) {
		
		List <Newsitem >newsitems = new ArrayList<Newsitem>();
		
		try {
			Parser parser = new Parser();
			parser.setInputHTML(content);
						
			// All news links are contained with in div of class newsSummary
			NodeFilter filterNode = new AndFilter(
					new TagNameFilter("div"), 
					new HasAttributeFilter("class", "newsSummary")
					);
	
			NodeList list = parser.extractAllNodesThatMatch(filterNode);
	
			int number_of_items = list.size();
			if (number_of_items > MAX_ITEMS) {
				log.info("Number of items in feed exceeds maximum; setting to " + MAX_ITEMS);
				number_of_items = MAX_ITEMS;
			}
			
			for (int i = 0; i < number_of_items; i++) {				
				Node tag = (Node) list.elementAt(i);				
				Node heading = tag.getFirstChild().getNextSibling();
				
				Tag link = (Tag) heading.getFirstChild();
								
				String url = AU_PREFIX + link.getAttribute("href");
				String title = link.toPlainTextString();				
				String description = heading.getNextSibling().getNextSibling().toPlainTextString();
			
				description = this.stripDescriptionMoreLink(description);
                
				Date date = null;
				String dateString = link.getNextSibling().getNextSibling().toPlainTextString();				
				if (dateString != null) {	               
		                // Parse this date.
		                SimpleDateFormat sdfInput = new SimpleDateFormat(AUCKLAND_UNIVERSITY_DATE_FORMAT); 
		                try {
		                    date = sdfInput.parse(dateString);
		                } catch (ParseException e) {
		                   log.error("Invalid date input; defaulting to null.");
		                }	                
		            } else {
		               log.error("Expected date field was not seen on request");
		            }
								
				Newsitem newsitem = new NewsitemImpl();
				newsitem.setTitle(title);
				newsitem.setUrl(url);
				newsitem.setDescription(description);
				newsitem.setDate(date);
				
				newsitems.add(newsitem);
			}
			
		} catch (ParserException e) {
			log.error("ParserException: " + e.getMessage(), e);
		}
			
		return newsitems;
	}
    
    
  
    
    private String stripDescriptionMoreLink(String content) {

        Pattern pattern;
        Matcher matcher;

        final String REGEX = "&nbsp;&gt;&gt;";
        pattern = Pattern.compile(REGEX);
        matcher = pattern.matcher(content);
        String result = matcher.replaceAll("");
        return result;
    }
	
	
}