package nz.gen.wellington.screenscrapers.auckland;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasChildFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.nodes.TextNode;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;



/**
 * Parses the Auckland Zoo latest news page for news items.
 * 
 * @author tony
 *
 */
public class AucklandZooNewsScraper extends ScreenScraperImpl {


	private static final String AUCKLAND_ZOO_PREFIX = "http://www.aucklandzoo.co.nz";
	private static final String ZOO_LATEST_NEWS_URL = "http://www.aucklandzoo.co.nz/aucklandzoo/news_main.php";

    Logger log = Logger.getLogger(AucklandZooNewsScraper.class);

	
	public String getPageURL() {
		return ZOO_LATEST_NEWS_URL;
	}

	
	
	public List <Newsitem> parseContent(String content) {        
        List <Newsitem> newItems = new ArrayList<Newsitem>();
        
        try {
            Parser parser = new Parser();
            parser.setInputHTML(content);

            // News item headings are h2 tags inside an HREF to the article page.	
            NodeFilter filterNode = new AndFilter(new LinkRegexFilter("/aucklandzoo/news_item.php.*", true), new HasChildFilter(new TagNameFilter("h2")));

            NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
            NodeList list = parser.extractAllNodesThatMatch(filter);
          
            for (int i = 0; i < list.size(); i++) {

                Tag tag = (Tag) list.elementAt(i);

                Newsitem newsitem = extractNewsitemFromTag(tag);

                // TODO push validation to newsitem.
                if (newsitem.getTitle() != null && newsitem.getDate() != null && newsitem.getUrl() != null && newsitem.getDescription() != null) {
                    newItems.add(newsitem);
                }

            }
        } catch (ParserException e) {
            log.error("ParserException: " + e.getMessage());
        }

        return newItems;
    }


    
    private Newsitem extractNewsitemFromTag(Tag tag) throws ParserException {
                
        Newsitem newsitem = new NewsitemImpl();
        // Extract the url.
        newsitem.setUrl(AUCKLAND_ZOO_PREFIX + tag.getAttribute("href"));
        
        // Look for the title and description in TextNodes
        NodeClassFilter description_filter = new NodeClassFilter(
                TextNode.class);
        
        Parser rowParser = new Parser();
        rowParser.setInputHTML(tag.toHtml());
        NodeList description_list = rowParser
                .extractAllNodesThatMatch(description_filter);

        // There should be 1 of them.           
        if (description_list.size() == 1) {
            String title = ((Node) description_list.elementAt(0)).getText();
            newsitem.setTitle(title);
        } else {
            System.err.print("Unexpected number of TextNodes.");
        }

        // The adjasent div contains the date string.
        Node date_div = tag.getNextSibling();
        String dateString = date_div.toPlainTextString();                 
        newsitem.setDate(parseDate(dateString, "dd / MM / yyyy"));
        

        // And the next div contains the description.
        Node description_div = tag.getNextSibling().getNextSibling().getNextSibling();
        newsitem.setDescription(description_div.toPlainTextString());

        return newsitem;
        }
    
}
