package nz.gen.wellington.screenscrapers.auckland;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.HasChildFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;


public class MAXXScraper extends ScreenScraperImpl {

	private static final int MAX_NEWSITEMS = 10;

    
    Logger log = Logger.getLogger(MAXXScraper.class);
    
    
	public String getPageURL() {
		return "http://www.rideline.co.nz/media_releases.html";
	}


    
	
	public List parseContent(String content) {
		List newsitems = new ArrayList();
        
		Parser parser = new Parser();
		try {
			parser.setInputHTML(content);
			NodeFilter linkFilter = new LinkRegexFilter("/media_releases.html\\?releaseid*");
            
            NodeFilter tableRowsFilter =
                    new AndFilter(                                                      
                            new org.htmlparser.filters.TagNameFilter("tr"),
                            new org.htmlparser.filters.HasChildFilter(                            
                            new AndFilter(
                            new org.htmlparser.filters.TagNameFilter("td"),
                            new org.htmlparser.filters.HasChildFilter(linkFilter)
                            )
                    )
            );            
            NodeFilter tableFilter = new HasChildFilter(tableRowsFilter);                   
            NodeList list = parser.extractAllNodesThatMatch(tableFilter);
            
			for (int i = 0; i < list.size() && i < MAX_NEWSITEMS; i++) {
				Newsitem newsitem = new NewsitemImpl();

              
				Tag enclosingTable = (Tag) list.elementAt(i);
			
			
                Parser linkParser = new Parser();
                linkParser.setInputHTML(enclosingTable.toHtml());
                NodeList linklist = linkParser.extractAllNodesThatMatch(linkFilter);
                        
                if (linklist.size() ==2 ) {
                    Tag linkTag = (Tag) linklist.elementAt(0);
                    
                    newsitem.setUrl("http://www.rideline.co.nz" + linkTag.getAttribute("href"));
                    newsitem.setTitle(stripSourceFromHeadline(linkTag.toPlainTextString().trim()));
                }
                
                Tag dateTag = getTagByClass("span", "steelsmall", enclosingTable.toHtml());
				if (dateTag != null) {
					String dateString = dateTag.toPlainTextString();
					newsitem.setDate(parseDate(dateString, "dd MMM yyyy"));
				}

				Tag descriptionTag = getTagByClass("td", "greynormal", enclosingTable.toHtml());
				if (descriptionTag != null) {
					newsitem.setDescription(descriptionTag.toPlainTextString().trim());
				}

				newsitems.add(newsitem);
			}

		} catch (ParserException e) {
			log.error(e.getMessage());
		}
		return newsitems;
	}


	
	private String stripSourceFromHeadline(String headline) {        
        Pattern p = Pattern.compile(".*?:(.*)");
        Matcher m = p.matcher(headline);

        if (m.matches()) {
            return m.group(1).trim();
        } else {
            return headline;
        }
    }



    private Tag getTagByClass(String tagname, String classname, String content)
			throws ParserException {

		Parser parser = new Parser();
		parser.setInputHTML(content);

		NodeFilter spanclassFilter = new AndFilter(new TagNameFilter(tagname), new HasAttributeFilter("class", classname));

		NodeFilter filter = new AndFilter(spanclassFilter, new NodeClassFilter(Tag.class));
		NodeList list = parser.extractAllNodesThatMatch(filter);
		if (list.size() == 1) {
			return (Tag) list.elementAt(0);
		}

		return null;
	}

}
