package nz.gen.wellington.screenscrapers.auckland;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.log4j.Logger;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class NorthShoreScraper extends ScreenScraperImpl {
    
    
    Logger log = Logger.getLogger(NorthShoreScraper.class);

    
    public String getPageURL() {
           return "http://www.northshorecity.govt.nz/your_council/news_releases/newsrel.htm";
    }

    public List parseContent(String content) {
       
        List newsitems = new ArrayList();

        try {
            Parser parser = new Parser();
            parser.setInputHTML(content);
            
            NodeFilter filter = new HasAttributeFilter("style", "font-weight: 400");
            NodeList list = parser.extractAllNodesThatMatch(filter);

            if (list.size() > 0) {
                Tag tag = (Tag) list.elementAt(0);
               
                Parser linkParser = new Parser();
                linkParser.setInputHTML(tag.toHtml());
                
                NodeFilter linkfilter = new TagNameFilter("a");
                NodeList links = linkParser.extractAllNodesThatMatch(linkfilter);
                               
                for (int i = 0; i < links.size(); i++) {                
                    Newsitem newsitem = new NewsitemImpl();
                                   
                    Tag linktag = (Tag) links.elementAt(i);         
                  
                    String url = "http://www.northshorecity.govt.nz/your_council/news_releases/" + linktag.getAttribute("href");
                    newsitem.setUrl(url);

                    String titleAndDateString = linktag.toPlainTextString();                    
                    String title = splitTitleFromTitleAndDate(titleAndDateString);
                    newsitem.setTitle(title.trim());

                    String dateString = splitDateStringFromTitleAndDate(titleAndDateString);                 
                    newsitem.setDate(parseDate(dateString, "dd/MM/yy"));
                    
                    newsitems.add(newsitem);
                }
                                
            }
                      
        } catch (ParserException e) {
            log.error("ParserException: " + e.getMessage());
        }
        
        
        return newsitems;
        
    }

    // TODO merge together
    private String splitTitleFromTitleAndDate(String titleAndDateString) {
        
        String REGEX = "(.*?)(\\d\\d/\\d\\d/\\d\\d)";

        Pattern pattern = Pattern.compile(REGEX);
        Matcher matcher = pattern.matcher(titleAndDateString);
        if (matcher.find()) {
            return (matcher.group(1));
        }
       
        return null;    
    }
    
        
    private String splitDateStringFromTitleAndDate(String titleAndDateString) {
        
        String REGEX = "(.*?)(\\d\\d/\\d\\d/\\d\\d)";

        Pattern pattern = Pattern.compile(REGEX);
        Matcher matcher = pattern.matcher(titleAndDateString);
        if (matcher.find()) {
            return (matcher.group(2));
        }
       
        return null;    
    }

}