package nz.gen.wellington.screenscrapers.auckland;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class VeoliaScraper extends ScreenScraperImpl implements ScreenScraper {

    private static final String VEOLIA_PREFIX = "http://www.connexauckland.co.nz/news_connex/";

    public String getPageURL() {
        return "http://www.connexauckland.co.nz/news_connex/index.asp?thm=2";
    }

    public List<Newsitem> parseContent(String content) {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();

        try {
            Parser parser = new Parser();
            parser.setInputHTML(content);
            NodeFilter filterNode = new AndFilter(new TagNameFilter("a"), new HasAttributeFilter("class", "subTableBlueLink"));

            NodeList list = parser.extractAllNodesThatMatch(filterNode);
            for (int i = 0; i < list.size(); i++) {
                Newsitem newsitem = new NewsitemImpl();
                Tag tag = (Tag) list.elementAt(i);

                newsitem.setTitle(tag.toPlainTextString());
                newsitem.setUrl(VEOLIA_PREFIX + tag.getAttribute("href"));
                newsitem.setDescription(StringEscapeUtils.unescapeHtml(tag.getParent().getParent().getNextSibling().getNextSibling().toPlainTextString().trim()));

                newsitems.add(newsitem);
            }

        } catch (ParserException e) {
            //log.error(e);
        }

        return newsitems;
    }

}
