package nz.gen.wellington.screenscrapers.twickenham;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class MogdenScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    private static final String URL_PREFIX = "http://www.thameswater.co.uk";
    Pattern datePattern = Pattern.compile("(\\d+ [a-zA-Z]+ \\d{4})\\s+-\\s+(.*)");

    public String getUrlStub() {
        return "mogden";
    }
    
    public String getPageURL() {
        return URL_PREFIX+ "/cps/rde/xchg/corp/hs.xsl/916.htm";
    }
    
    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();

        Tag contentDiv = this.extractTagByClassName(content, "section-highlights");
        NodeList headings = this.extractTagsByName(contentDiv.toHtml(), "h4");
        for (int i = 0; i < headings.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
            Tag headingTag = (Tag) headings.elementAt(i);
            Tag linkTag = (Tag) headingTag.getFirstChild();

            String dateTitle = linkTag.toPlainTextString().trim();
            Matcher matcher = datePattern.matcher(dateTitle);
            if (matcher.matches()) {
                final String dateString = matcher.group(1).trim();
                final String title = matcher.group(2).trim();
                newsitem.setTitle(title);
                newsitem.setUrl(URL_PREFIX + linkTag.getAttribute("href"));
                newsitem.setDate(this.parseDate(dateString, "dd MMMMM yyyy"));
                Node descriptionParagraph = headingTag.getNextSibling().getNextSibling();
				newsitem.setDescription(StringEscapeUtils.unescapeHtml(descriptionParagraph.toPlainTextString().trim()));
                newsitems.add(newsitem);
            }
        }

        return newsitems;
    }

}