package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class CCDHBScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    Logger log = Logger.getLogger(CCDHBScraper.class);
    
    private static final String CCDHB_PREFIX = "http://www.ccdhb.org.nz";
    
    public String getUrlStub() {
		return "ccdhb";
	}

	public String getPageURL() {
        return CCDHB_PREFIX + "/news/";
    }

    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();
        
        Parser parser = new Parser();
        parser.setInputHTML(content);
     
        NodeFilter linkFilter = new LinkRegexFilter(".*200\\d_archive.*");
        NodeList list = parser.extractAllNodesThatMatch(linkFilter);
        
        for (int i = 0; i < list.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
            Tag linkTag = (Tag) list.elementAt(i);
            
            final String href = linkTag.getAttribute("href");
            log.debug("href is: " + href);
            String linkHref = CCDHB_PREFIX + "/news/" + href;
            if (href.startsWith("/News")) {
                linkHref = CCDHB_PREFIX + href;
            }
            newsitem.setUrl(linkHref);
        
            String title = StringEscapeUtils.unescapeHtml(linkTag.getParent().toPlainTextString()).trim();
            title = title.replaceAll("\\(\\d\\d/\\d\\d/\\d\\d\\)" , "").replaceAll("\\s+", " ").trim();
            newsitem.setTitle(title);
      
            Pattern dateMatcher = Pattern.compile(".*(\\d\\d_\\d\\d_\\d\\d).*");
            Matcher matcher = dateMatcher.matcher(newsitem.getUrl());
            if (matcher.matches()) {
                final String dateString = matcher.group(1);
                newsitem.setDate(parseDate(dateString, "yy_MM_dd"));                
                newsitems.add(newsitem);
            }
        }

        return newsitems;
    }

}