package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class CatsProtectionLeagueScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.cpl-wellington.org.nz";
	
	public String getUrlStub() {
		return "cpl";
	}

	public String getCharacterEncoding() {
		return "UTF-8";
	}

	public String getPageURL() {
		return "http://www.cpl-wellington.org.nz/cpl-news";
	}

	public List<Newsitem> parseContent(String content) throws Exception {
        final List<Newsitem> newsitems = new ArrayList<Newsitem>();

        final NodeList headings = this.extractTagsByClassName(content, "views-field views-field-title");
        for (int i = 0; i < headings.size(); i++) {
        	final Newsitem newsitem = new NewsitemImpl();

        	final Tag headingTag = (Tag) headings.elementAt(i);
        	final Tag titleLinkTag = (Tag) headingTag.getFirstChild().getNextSibling().getFirstChild();        	
			
        	String dateString = headingTag.getNextSibling().getNextSibling().toPlainTextString().trim();
			dateString = dateString.substring(4, dateString.length());			
			newsitem.setDate(parseDate(dateString, "dd MMMMM yyyy"));
			
        	newsitem.setTitle(titleLinkTag.toPlainTextString());
        	newsitem.setUrl(URL_PREFIX + titleLinkTag.getAttribute("href"));
        	
        	final Node descriptionDiv = headingTag.getNextSibling().getNextSibling().getNextSibling().getNextSibling();
			newsitem.setDescription(StringEscapeUtils.unescapeHtml(descriptionDiv.toPlainTextString().trim()));
			
            newsitems.add(newsitem);
        }        
        return newsitems;
    }

}
