package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class CityGalleryScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://citygallery.org.nz";

	public String getUrlStub() {
		return "city-gallery";
	}
	
	@Override
	public String getCharacterEncoding() {
		return "UTF-8";
	}
	
	public String getPageURL() {
		return URL_PREFIX + "/news";
	}

	public List<Newsitem> parseContent(String content) throws Exception {
		final List<Newsitem> newsitems = new ArrayList<Newsitem>();
		NodeList items = this.extractTagsByClassName(content, "news-item");
		for (int i = 0; i < items.size(); i++) {
			final Newsitem newsitem = new NewsitemImpl();			 
			Tag newsitemArticleTag = (Tag) items.elementAt(i);			
			
			Node linkTag = newsitemArticleTag.getNextSibling().getNextSibling();
			final String href = ((Tag) linkTag).getAttribute("href");
			newsitem.setUrl(URL_PREFIX + href);
			
			Node figureTag = linkTag.getFirstChild().getNextSibling();
			
			Node imageTag = figureTag.getNextSibling();
			final String imageUri = ((Tag) imageTag).getAttribute("src");
			newsitem.setImage(URL_PREFIX + imageUri);
			
			Node headingTag = imageTag.getNextSibling().getNextSibling().getNextSibling();
			final String title = headingTag.toPlainTextString();
			newsitem.setTitle(title);
			
			Node dateTag = linkTag.getNextSibling();
			final String dateString = dateTag.toPlainTextString();
			newsitem.setDate(parseDate(dateString, "dd/MM/yyyy"));
			
			Node descriptionTag = dateTag.getNextSibling().getNextSibling();
			final String description = descriptionTag.toPlainTextString();
			newsitem.setDescription(description);
					
			newsitems.add(newsitem);			 
		}
		return newsitems;
	}

}
