package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class ClubWeeklyScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    private static final String URL_PREFIX = "http://www.clubrugby.co.nz/wellington/";
	Logger log = Logger.getLogger(ClubWeeklyScraper.class);
    
	public String getCharacterEncoding() {
        return "Windows-1252";
    }
    
	public String getUrlStub() {
		return "clubweekly";
	}
    
    public String getPageURL() {
        return "http://www.clubrugby.co.nz/wellington/story-archive.php";
    }
    
    @Override
	public String getName() {
		return "Wellington Club Rugby stories";
	}

	public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();
        Parser parser = new Parser();
        parser.setInputHTML(content);        
        NodeList list = extractTagsByClassName(content, "storyTitle");
        for (int i = 0; i < list.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
            final Tag tag = (Tag) list.elementAt(i);

            final Tag linkTag = (Tag) tag.getFirstChild();
            newsitem.setTitle(linkTag.toPlainTextString().trim());
            newsitem.setUrl(URL_PREFIX + linkTag.getAttribute("href"));

            final Node dateByLine = tag.getNextSibling().getNextSibling();
			final String dateByLineString = dateByLine.toPlainTextString();
			final String dateString = dateByLineString.split("\\|")[1].trim();
            newsitem.setDate(parseDate(dateString, "dd MMMMM yyyy"));            
            String description = StringEscapeUtils.unescapeHtml(dateByLine.getNextSibling().getNextSibling().toPlainTextString().trim());
            description = description.replaceAll("\\s+", " ").trim();
            description = description.replaceAll("More$", "");
			newsitem.setDescription(description);
            newsitems.add(newsitem);
        }

        return newsitems;
    }
    
}
