package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class CricketWellingtonScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.cricketwellington.co.nz";
	
	public String getCharacterEncoding() {
		return "UTF8";
	}
		
	public String getUrlStub() {
		return "cricketwellington";
	}

	public String getPageURL() {
		return "http://www.cricketwellington.co.nz/net/news/";
	}
	
	@Override
	public String getName() {
		return "Cricket Wellington news";
	}

	public List<Newsitem> parseContent(String content) throws Exception {
		List<Newsitem> newsitems = new ArrayList<Newsitem>();		
		Tag contentDiv = this.extractTagById(content, "ctl00_plcContent_uctlNews_hgcNews");
		
		NodeList list = this.extractTagsByClassName(contentDiv.toHtml(), "summary");
		for (int i = 0; i < list.size(); i++) {
			Tag tag = (Tag) list.elementAt(i);			
			Newsitem newsitem = new NewsitemImpl();			
			newsitem.setTitle(tag.getFirstChild().getNextSibling().toPlainTextString());
			
			Tag linkTag = (Tag) tag.getFirstChild().getNextSibling();			
			newsitem.setUrl(URL_PREFIX + linkTag.getAttribute("href"));
			
			final String dateString = this.extractTagByClassName(tag.toHtml(), "date").toPlainTextString();
			newsitem.setDate(parseDate(dateString, "d/MM/yyyy"));
			
			Tag descriptionTag = (Tag) this.extractTagByClassName(tag.toHtml(), "short_description");
			newsitem.setDescription(descriptionTag.toPlainTextString());			
			newsitems.add(newsitem);
		}				
		return newsitems;			
	}

}
