package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.util.NodeList;

public class KaroriCricketScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    private static final String KARORI_CRICKET_PREFIX = "http://www.karoricricket.org.nz";

    public String getPageURL() {
        return KARORI_CRICKET_PREFIX;
    }
        
    public String getUrlStub() {
		return "karoricricket";
	}

	public List<Newsitem> parseContent(String content) throws Exception {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();

        Parser parser = new Parser();
        parser.setInputHTML(content);

        NodeFilter filterNode = new HasAttributeFilter("class", "wrap");
        NodeList list = parser.extractAllNodesThatMatch(filterNode);
        for (int i = 0; i < list.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
            Tag tag = (Tag) list.elementAt(i);

            Tag titleTag = (Tag) tag.getFirstChild().getNextSibling();
            newsitem.setTitle(titleTag.toPlainTextString());
           
            Tag dateTag = (Tag) titleTag.getNextSibling().getNextSibling();
            final String dateString = dateTag.toPlainTextString();           
            newsitem.setDate(parseDate(dateString, "EEEE MMMM dd, yyyy"));
            
            Tag descriptionAndHrefTag = (Tag) dateTag.getNextSibling().getNextSibling();            
            Tag hrefTag = (Tag) descriptionAndHrefTag.getLastChild();
            newsitem.setUrl(KARORI_CRICKET_PREFIX + hrefTag.getAttribute("href"));            
            newsitem.setDescription(StringEscapeUtils.unescapeHtml(descriptionAndHrefTag.getFirstChild().toPlainTextString()).trim());
                        
            newsitems.add(newsitem);
        }
        return newsitems;
    }

}
