package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class KaroriSanctuaryScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.visitzealandia.com";
	
	private static final Pattern headlineWithDatePrefix = Pattern.compile("^(\\d\\d/\\d\\d/\\d\\d).*");	// TODO needs to match 8/9/2010 style dates as well.
	
	public String getCharacterEncoding() {
		return "UTF-8";
	}
	
	public String getUrlStub() {
		return "karorisanctuary";
	}

	public String getPageURL() {
		return "http://www.visitzealandia.com/Site/Zealandia_Home/Inside/News/Default.aspx";
	}
	
    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsItems = new ArrayList<Newsitem>();

        NodeList list = this.extractTagsByClassName(content, "MoSTDocumentListHeading");        
        for (int i = 0; i < list.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
         
            Tag titleDivTag = (Tag) list.elementAt(i);
            Tag headingTag = (Tag) titleDivTag.getFirstChild();
            newsitem.setUrl(URL_PREFIX + headingTag.getAttribute("href"));

    		final String linkText = headingTag.toPlainTextString().trim();
            extractHeadlingAndDateIfAvailable(newsitem, linkText);
            newsItems.add(newsitem);
        }

        return newsItems;
    }

	private void extractHeadlingAndDateIfAvailable(Newsitem newsitem, String linkText) {
		Matcher matcher = headlineWithDatePrefix.matcher(linkText);
		if (matcher.matches()) {
			final String dateString = matcher.group(1);
			newsitem.setTitle(linkText.replaceFirst(dateString, "").trim());
			newsitem.setDate(this.parseDate(dateString, "dd/MM/yy"));            	
		} else {
			newsitem.setTitle(linkText);
		}
	}

}
