package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class NorthernCourierScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    private static final String NC_PREFIX = "http://www.localmedia.co.nz";

    private static final String NORTHEN_COURIER_DATE_FORMAT = "ddMMyy";

    
    public String getUrlStub() {
		return "northerncourier";
	}

	public String getPageURL() {
        return "http://www.localmedia.co.nz/northerncourier/";
    }

    public String getCharacterEncoding() {
        return "windows-1251";
    }

    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();

        Tag contentDiv = this.extractTagById(content, "content");
        Parser parser = new Parser();
        parser.setInputHTML(contentDiv.toHtml());

        NodeList links = extractNewsLinks(parser, storyLinkRegex());
  
        for (int i = 0; i < links.size(); i++) {
            Tag linktag = (Tag) links.elementAt(i);
       
            Tag titleTag = extractTagByClassName(linktag.toHtml(), "style9");
            if (titleTag != null) {
                Newsitem newsitem = new NewsitemImpl();
                newsitem.setTitle(titleTag.toPlainTextString());
                
                String href = linktag.getAttribute("href");
                if (href.startsWith("ph")) {
                    href = "/petoneherald/" + href;                    
                }
                        
                
                String url = NC_PREFIX + href;
                url = url.replaceAll(" ", "%20");
                newsitem.setUrl(url);
                
                Date dateFromUrl = extractDateFromUrl(linktag.getAttribute("href"));
                if (dateFromUrl != null) {
                    newsitem.setDate(dateFromUrl);
                }
                newsitems.add(newsitem);
                
                try {
                    String description = linktag.getNextSibling().getNextSibling().toPlainTextString().trim();
                    newsitem.setDescription(description);                   
                } catch (Exception e) {
                    // TODO logging.
                }
                    
            }
        }

        return newsitems;
    }

	protected String storyLinkRegex() {
		return "/northerncourier/stories/nc.*";
	}
	

    private Date extractDateFromUrl(String url) {
        String dateString = extractStringDateFromUrl(url);
        if (dateString != null) {
            return parseDate(dateString, NORTHEN_COURIER_DATE_FORMAT);
        }
        return null;
    }

    private String extractStringDateFromUrl(String url) {
        Pattern p = Pattern.compile(".*(\\d{6}).*");
        final Matcher m = p.matcher(url);
        if (m.matches()) {
            return m.group(1);
        }
        return null;
    }

}
