package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class OlympicAFCScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.olympicafc.org.nz/";
		
	public String getCharacterEncoding() {
		return "UTF-8";
	}
	
	public String getUrlStub() {
		return "olympic-afc";
	}

	public String getPageURL() {
		return URL_PREFIX;
	}
	
    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsItems = new ArrayList<Newsitem>();

        NodeList list = this.extractTagsByClassName(content, "newsheadline");        
        for (int i = 0; i < list.size(); i++) {
        	Tag headlineTag = (Tag) list.elementAt(i);

        	Newsitem newsitem = new NewsitemImpl();         
        	newsitem.setTitle(headlineTag.toPlainTextString());        	
            
        	final String newsitemHtml = headlineTag.getParent().toHtml();
            
        	Tag dateTag = this.extractTagByClassName(newsitemHtml, "tinytext");
        	final String dateString = dateTag.toPlainTextString().trim();
        	newsitem.setDate(parseDate(dateString, "yyyy-MM-dd"));          
        	newsitem.setDescription(dateTag.getNextSibling().getNextSibling().toPlainTextString());
        	
        	Tag linkTag = (Tag) this.extractTagByClassName(newsitemHtml, "smallorange").getFirstChild();
        	newsitem.setUrl(URL_PREFIX + linkTag.getAttribute("href"));

            newsItems.add(newsitem);
        }

        return newsItems;
    }
    
}
