package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class PCCScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	final String URL_PREFIX = "http://www.pcc.govt.nz/News---Events/Latest-News";
	
	public String getCharacterEncoding() {
		return "UTF-8";
	}
	
	public String getPageURL() {
		return URL_PREFIX;
	}

	public List<Newsitem> parseContent(String content) throws Exception {
		List<Newsitem> newsitems = new ArrayList<Newsitem>();
		
		Node latestNewsHeadingTag = this.extractTagsByName(content, "h1").elementAt(0);
		Node newsitemsListTag = latestNewsHeadingTag.getNextSibling()
				.getNextSibling().getNextSibling().getNextSibling()
				.getNextSibling().getNextSibling().getNextSibling()
				.getNextSibling();
		
		NodeList links = this.extractTagsByName(newsitemsListTag.toHtml(), "li");
		for (int i = 0; i < links.size(); i++) {
			Tag linkTag = (Tag) links.elementAt(i);

			Newsitem newsitem = new NewsitemImpl();
			Tag hrefTag = (Tag) linkTag.getFirstChild().getNextSibling();
			newsitem.setTitle(hrefTag.toPlainTextString());
			newsitem.setUrl(URL_PREFIX + hrefTag.getAttribute("href"));
			
			String dateString = linkTag.toPlainTextString().replace(newsitem.getTitle(), "");
			dateString = dateString.replace(" -", " 2009").trim();
			newsitem.setDate(parseDate(dateString, "dd MMM yyyy"));
			newsitems.add(newsitem);
		}

		return newsitems;
	}

	public String getUrlStub() {
		return "pcc";
	}

}
