package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;


public class PetoneHeraldScraper extends ScreenScraperImpl implements ResolvableScreenScraper {
	
	public String getUrlStub() {
		return "petoneherald";
	}
	
	public String getCharacterEncoding() {
		return "ISO-8859-1";
	}



	public String getPageURL() {
		return "http://www.localmedia.co.nz/petoneherald/";
	}

	
	protected String storyLinkRegex() {
		return "/petoneherald/stories/ph\\d\\d\\d\\d\\d\\d/";
	}
	
	
	public List<Newsitem> parseContent(String content) throws ParserException {
		List<Newsitem> newsitems = new ArrayList<Newsitem>();
		Tag contentDiv = this.extractTagById(content, "headlines");
		NodeList links = extractLinks(contentDiv.toHtml(), storyLinkRegex());
		for (int i = 0; i < links.size(); i++) {
			Tag linktag = (Tag) links.elementAt(i);
			if (!linktag.toPlainTextString().contains("table of contents")) {
				Newsitem newsitem = new NewsitemImpl();

				String title = linktag.toPlainTextString().replace("&bull;","").trim();
				title = StringEscapeUtils.unescapeHtml(title);
				newsitem.setTitle(title);
				newsitem.setUrl("http://www.localmedia.co.nz" + linktag.getAttribute("href"));
				newsitems.add(newsitem);

				final String dateString = extractStringDateFromUrl(linktag
						.getAttribute("href"));
				newsitem.setDate(parseDate(dateString, "ddMMyy"));
			}
		}
		return newsitems;
	}

	private String extractStringDateFromUrl(String url) {
		Pattern p = Pattern.compile(".*(\\d{6}).*");
		final Matcher m = p.matcher(url);
		if (m.matches()) {
			return m.group(1);
		}
		return null;
	}		
	
}
