package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class PhoenixScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

    private static final String URL_PREFIX = "http://www.wellingtonphoenix.com";
    
    Logger log = Logger.getLogger(PhoenixScraper.class);

       
    public String getUrlStub() {
		return "phoenix";
	}

	public String getPageURL() {
        return "http://www.wellingtonphoenix.com/default.aspx?s=newscentral";
    }
    
    
    public String getCharacterEncoding() {
        return "UTF8";
    }

    public List<Newsitem> parseContent(String content) throws ParserException {
        List<Newsitem> newsitems = new ArrayList<Newsitem>();

        Parser parser = new Parser();
        parser.setInputHTML(content);

        NodeFilter filterNode = new HasAttributeFilter("class", "pullquotetitle");

        NodeList list = parser.extractAllNodesThatMatch(filterNode);

        for (int i = 0; i < list.size(); i++) {
            Newsitem newsitem = new NewsitemImpl();
            Tag tag = (Tag) list.elementAt(i);

            newsitem.setTitle(tag.toPlainTextString());          

            Node dateTag = tag.getNextSibling().getNextSibling();            
            final String dateString = dateTag.toPlainTextString().trim();         
            newsitem.setDate(parseDate(dateString, "EEEE, dd MMMM yyyy"));

            Tag linkTag = (Tag) dateTag.getNextSibling().getNextSibling().getNextSibling().getNextSibling();
            newsitem.setUrl(URL_PREFIX + StringEscapeUtils.unescapeHtml(linkTag.getAttribute("href")));

            Node descriptionTag = linkTag.getPreviousSibling().getPreviousSibling();
			newsitem.setDescription(descriptionTag.toPlainTextString().trim());
            
            newsitems.add(newsitem);
        }

        return newsitems;
    }

}
