package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;
import org.joda.time.DateTime;

public class SistersOfCompassionScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.compassion.org.nz";
	
	@Override
	public String getCharacterEncoding() {
		return "windows-1252";
	}

	public String getPageURL() {
		DateTime now = new DateTime();
		return URL_PREFIX + "/news/" + now.toString("YYYY") + ".php";
	}

	public List<Newsitem> parseContent(String content) throws Exception {		
		List<Newsitem> newsitems = new ArrayList<Newsitem>();
		NodeList options = this.extractTagsByClassName(content, "newshead");
		for (int i = 0; i < options.size(); i++) {
			Tag tag = (Tag) options.elementAt(i);
			Newsitem newsitem = new NewsitemImpl();

			Tag headlineLink = (Tag) tag.getFirstChild();
			newsitem.setTitle(headlineLink.toPlainTextString().trim());
			newsitem.setUrl(URL_PREFIX + StringEscapeUtils.unescapeHtml(headlineLink.getAttribute("href")));

			Node standfirstDiv = tag.getNextSibling();
			newsitem.setDescription(standfirstDiv.toPlainTextString());

			Node dateDiv = standfirstDiv.getNextSibling();
			
			final String dateString = dateDiv.toPlainTextString();
			newsitem.setDate(parseDate(dateString, "dd MMMMM yyyy"));
			newsitems.add(newsitem);
		}
		return newsitems;
	}
	
	public String getUrlStub() {
		return "compassion";
	}

}
