package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class UnitedFutureScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	public String getPageURL() {
		return "http://www.unitedfuture.org.nz/default,1274,dunne_calls_on_city_council_to_defer_johnsonville_change_by_12_months.sm";
	}

	public List<Newsitem> parseContent(String content) throws Exception {		
		List<Newsitem> newsitems = new ArrayList<Newsitem>();

		Tag contentDiv = this.extractTagById(content, "sidebar");
		
		Tag listDiv = this.extractTagByClassName(contentDiv.toHtml(), "subnav");
		NodeList links = this.extractTagsByName(listDiv.toHtml(), "li");
		
		Pattern pattern = Pattern.compile(".*?((\\d{4}-\\d{2}-\\d{2}) \\d{2}:\\d{2}:\\d{2}\\.\\d{3})$");
		for (int i = 0; i < links.size(); i++) {
			Newsitem newsitem = new NewsitemImpl();
			Tag tag = (Tag) links.elementAt(i);
			Tag linkTag = (Tag) tag.getFirstChild();

			String titleAndDateString = linkTag.toPlainTextString().replaceAll("\\s", " ").trim();
			
			titleAndDateString = StringEscapeUtils.unescapeHtml(titleAndDateString);			
			Matcher matcher = pattern.matcher(titleAndDateString);
			
			if (matcher.matches()) {
				final String dateTimeString = matcher.group(1);
				final String dateString = matcher.group(2);
				
				newsitem.setTitle(titleAndDateString.replace(dateTimeString, "").trim());
				String url = "http://www.unitedfuture.org.nz" + linkTag.getAttribute("href");
				url = url.split(";jsession")[0];
				newsitem.setUrl(url);
			
				newsitem.setDate(this.parseDate(dateString, "yyyy-MM-dd"));
				newsitems.add(newsitem);
			}
			
		}
		return newsitems;
	}

	public String getUrlStub() {
		return "united-future";
	}

}
