package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class WellingtonAirportScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.wellingtonairport.co.nz";

	public String getCharacterEncoding() {
		return "UTF-8";
	}

	public String getPageURL() {
		return URL_PREFIX + "/news/";
	}
	
	@Override
	public String getName() {
		return "Wellington Airport news";
	}

	public List<Newsitem> parseContent(String content) throws Exception {
		 NodeList items = extractTagsByClassName(content, "h2");

		 List<Newsitem> newsitems = new ArrayList<Newsitem>();
		 for (int i = 0; i < items.size(); i++) {			 
			 final Node headingNode = items.elementAt(i);
			 
			 final Newsitem newsitem = new NewsitemImpl();
			 Tag headlineTag = (Tag) headingNode.getFirstChild();
			 headlineTag.toHtml();
			
			 newsitem.setTitle(headlineTag.toPlainTextString());
			 newsitem.setUrl(URL_PREFIX + headlineTag.getAttribute("href"));
			
			 final Node dateTag = headingNode.getParent().getFirstChild().getNextSibling();
			 final String dateString = dateTag.toPlainTextString();
			 newsitem.setDate(parseDate(dateString, "dd MMMMM yyyy"));
			 
			 newsitem.setDescription(StringEscapeUtils.unescapeHtml(headingNode.getNextSibling().getNextSibling().toPlainTextString()).trim());
			 
			 newsitems.add(newsitem);				
		}
		return newsitems;
	}
	
	public String getUrlStub() {
		return "wial";
	}
	
}
