package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.LinkRegexFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class WellingtonBasketballAssociationScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.wellingtonbasketball.co.nz/";
	
	public String getUrlStub() {
		return "wellingtonbasketballassociation";
	}

	public String getPageURL() {
		return "http://www.wellingtonbasketball.co.nz/cgi-bin/home.pl";
	}

	public List<Newsitem> parseContent(String content) throws Exception {		
        List<Newsitem> newsItems = new ArrayList<Newsitem>();
        String mainContent = extractMainContentCell(content);
        
        String[] segments = mainContent.split("news_id");
        
        Parser parser = new Parser();
  
        parser.setInputHTML(mainContent);
        NodeFilter filterNode = new LinkRegexFilter("home.pl\\?news_id.*");
        NodeFilter filter = new AndFilter(filterNode, new NodeClassFilter(Tag.class));
        NodeList list = parser.extractAllNodesThatMatch(filter);
        
        for (int i = 0; i < list.size(); i++) {
            Tag linkTag = (Tag) list.elementAt(i);
                 
        	Newsitem newsitem = new NewsitemImpl();
        	newsitem.setUrl(URL_PREFIX + "cgi-bin/" + linkTag.getAttribute("href"));
                	
        	String segment = segments[i];        	
        	
        	Pattern headlinePattern = Pattern.compile(".*?<h2>(.*?)</h2>.*", Pattern.DOTALL | Pattern.CASE_INSENSITIVE);
            Matcher headlineMatcher = headlinePattern.matcher(segment);
            if (headlineMatcher.matches()) {
                final String headline = headlineMatcher.group(1).trim();              
                newsitem.setTitle(headline);
            }
            
        	Pattern dateMatcher = Pattern.compile(".*?<b>(.*?)</b>.*", Pattern.DOTALL | Pattern.CASE_INSENSITIVE);
            Matcher matcher = dateMatcher.matcher(segment);         
            if (matcher.matches()) {
                final String dateString = matcher.group(1);                                
                newsitem.setDate(parseDate(dateString, "dd MMMMM yyyy"));                
            }
   		            	
        	newsItems.add(newsitem);
        }
          
        return newsItems;		
	}

	
	private String extractMainContentCell(String content) throws ParserException {		
		return extractTagByClassName(content, "body").toHtml();
	}

}
