package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class WellingtonChildrensHospitalScraper extends ScreenScraperImpl implements ResolvableScreenScraper {

	private static final String URL_PREFIX = "http://www.justforkids.org.nz";
	private static final String DATE_FORMAT = "dd MMMMM yyyy";

	public String getCharacterEncoding() {
		return "UTF-8";
	}
	
	public String getPageURL() {
		return URL_PREFIX + "/news/";
	}
	
	public List<Newsitem> parseContent(String content) throws Exception {
		final List<Newsitem> newsitems = new ArrayList<Newsitem>();		
		content = stripHtmlComments(content);
		final NodeList links = extractTagsByClassName(content, "title");
		for (int i = 0; i < links.size(); i++) {
			final Tag titleSpan = (Tag) links.elementAt(i);			

			final Newsitem newsitem = new NewsitemImpl();
			newsitem.setTitle(StringEscapeUtils.unescapeHtml(titleSpan.toPlainTextString()));
					
			final Node dateSpan = titleSpan.getNextSibling().getNextSibling().getNextSibling();
			newsitem.setDate(parseDate(dateSpan.toPlainTextString(), DATE_FORMAT));
			
			final Node descriptionSpan = dateSpan.getNextSibling().getNextSibling();
			newsitem.setDescription(StringEscapeUtils.unescapeHtml(descriptionSpan.toPlainTextString().replaceAll("\\s+", " ").trim()));
			
			Tag link = (Tag) descriptionSpan.getNextSibling().getNextSibling();
			newsitem.setUrl(URL_PREFIX + link.getAttribute("href"));

			if (newsitem.getDate() != null) {
				newsitems.add(newsitem);
			}
		}
		return newsitems;
	}

	public String getUrlStub() {
		return "wellington-childrens-hospital";
	}

}
