package nz.gen.wellington.screenscrapers.wellington;

import java.util.ArrayList;
import java.util.List;

import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.apache.commons.lang.StringEscapeUtils;
import org.htmlparser.Node;
import org.htmlparser.Tag;
import org.htmlparser.util.NodeList;

public class WellingtonLionsScraper extends ScreenScraperImpl implements ResolvableScreenScraper {
	
	private static final String URL_PREFIX = "http://www.wellingtonlions.co.nz";

	
	public String getCharacterEncoding() {
		return "UTF-8";
	}

	public String getPageURL() {
		return URL_PREFIX;
	}
	
	public String getUrlStub() {
		return "wellingtonlions";
	}

	
	public List<Newsitem> parseContent(String content) throws Exception {
		List<Newsitem> newsitems = new ArrayList<Newsitem>();			
		NodeList newsitemListElements = this.extractTagsByNameAndClassName(content, "li", "latestnews");		
		for (int i = 0; i < newsitemListElements.size(); i++) {
	            Tag tag = (Tag) newsitemListElements.elementAt(i);
	            Newsitem newsitem = new NewsitemImpl();
	            
	            Tag titleTag = (Tag) tag.getFirstChild().getNextSibling().getFirstChild();
				newsitem.setTitle(titleTag.toPlainTextString().trim());
				newsitem.setUrl(URL_PREFIX + titleTag.getAttribute("href"));
				
				Node dateTag = titleTag.getParent().getNextSibling().getNextSibling();
				final String dateString = dateTag.toPlainTextString().split(",")[1].trim();
				newsitem.setDate(this.parseDate(dateString, "dd MMMMM yyyy"));
				
				Node descriptionTag = dateTag.getNextSibling().getNextSibling();								
				String description = descriptionTag.toPlainTextString();		
				newsitem.setDescription(StringEscapeUtils.unescapeHtml(description.split("\\u00A0")[0]));
	            newsitems.add(newsitem);
	        }
		  		  
		return newsitems;
	}

	

}
