package nz.gen.wellington.screenscrapers.wimbledon;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import nz.co.searchwellington.utils.UrlFilters;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ScreenScraperImpl;

import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.Tag;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;

public class SuttonScraper extends ScreenScraperImpl {
    

    public String getPageURL() {
        return "http://www.sutton.gov.uk/news/latest/";
    }
    
    
    
    public List <Newsitem> parseContent(String content) {
     
        try {
            String contentDiv = extractContentDiv(content);
            if (contentDiv != null) {
                return extractNewsitemsFromContentDiv(contentDiv);
            }

        } catch (ParserException p) {
            // TODO log
        }
        return null;

    }

    
    
    
    private List <Newsitem> extractNewsitemsFromContentDiv(String contentDiv) throws ParserException {
    
        List <Newsitem> newsitems = new ArrayList <Newsitem> ();
        
        Parser parser = new Parser();
        parser.setInputHTML(contentDiv);
      
        NodeFilter listElementFilter = new TagNameFilter("LI");
        NodeList list = parser.extractAllNodesThatMatch(listElementFilter);
        
        for (int i=0; i < list.size(); i++) {            
            Tag listElement = (Tag) list.elementAt(i);
            Newsitem newsitem = new NewsitemImpl();
                  
            Tag linkTag = (Tag) listElement.getFirstChild();
            String url =  "http://www.sutton.gov.uk" + linkTag.getAttribute("href");          
           newsitem.setUrl(url);
            
            String titleAndDate = linkTag.toPlainTextString();
            newsitem.setTitle(splitTitleFromTitleAndDate(titleAndDate));
                        
            String dateString = splitDateFromTitleAndDate(titleAndDate);            
            newsitem.setDate(parseDate(dateString, "dd/MM/yyyy"));
                                   
            newsitem.setDescription(org.apache.commons.lang.StringEscapeUtils.unescapeHtml(UrlFilters.stripHtmlTags(linkTag.getNextSibling().toPlainTextString())).trim());
            
            newsitems.add(newsitem);
        }
      
        return newsitems;
    }

    
    
    private String splitTitleFromTitleAndDate(String titleAndDateString) {
        
        String REGEX = "(.*?) - (\\d\\d/\\d\\d/\\d\\d\\d\\d)";

        Pattern pattern = Pattern.compile(REGEX);
        Matcher matcher = pattern.matcher(titleAndDateString);
        if (matcher.find()) {
            return (matcher.group(1));
        }
       
        return null;    
    }
  
  
  private String splitDateFromTitleAndDate(String titleAndDateString) {
        
        String REGEX = "(.*?) - (\\d\\d/\\d\\d/\\d\\d\\d\\d)";

        Pattern pattern = Pattern.compile(REGEX);
        Matcher matcher = pattern.matcher(titleAndDateString);
        if (matcher.find()) {
            return (matcher.group(2));
        }
       
        return null;    
    }
    
    
    

    private String extractContentDiv(String content) throws ParserException {

        Parser parser = new Parser();
        parser.setInputHTML(content);
      
        NodeFilter contentDivFilter = new AndFilter(new TagNameFilter("DIV"), new HasAttributeFilter("id", "channelContentList"));
        NodeList list = parser.extractAllNodesThatMatch(contentDivFilter);
        if (list.size() == 1) {
            return ((Tag) list.elementAt(0)).toHtml();
        }

        return null;
    }

    

    
}
