package nz.gen.wellington.servlets.screenscrapers;

import java.net.MalformedURLException;
import java.net.URL;

import nz.gen.wellington.screenscrapers.Newsitem;

import com.sun.syndication.feed.module.georss.GeoRSSModule;
import com.sun.syndication.feed.module.georss.W3CGeoModuleImpl;
import com.sun.syndication.feed.module.georss.geometries.Position;
import com.sun.syndication.feed.module.mediarss.MediaEntryModuleImpl;
import com.sun.syndication.feed.module.mediarss.types.MediaContent;
import com.sun.syndication.feed.module.mediarss.types.Metadata;
import com.sun.syndication.feed.module.mediarss.types.Thumbnail;
import com.sun.syndication.feed.module.mediarss.types.UrlReference;
import com.sun.syndication.feed.synd.SyndContent;
import com.sun.syndication.feed.synd.SyndContentImpl;
import com.sun.syndication.feed.synd.SyndEntry;
import com.sun.syndication.feed.synd.SyndEntryImpl;

public class NewsitemToSyndEntryService {
		
	public NewsitemToSyndEntryService() {		
	}
	
	public SyndEntry makeSyndEntryFromNewsitem(Newsitem newsitem) {
		SyndEntry entry = new SyndEntryImpl();
		SyndContent description;

		entry = new SyndEntryImpl();
		entry.setTitle(newsitem.getTitle());
		entry.setLink(newsitem.getUrl());
		if (newsitem.getDate() != null) {
			entry.setPublishedDate(newsitem.getDate());
		}
		description = new SyndContentImpl();
		description.setType("text/plain");
		description.setValue(newsitem.getDescription());
		entry.setDescription(description);
		
		final String imageUrl = newsitem.getImage();
		if (imageUrl != null) {
			addMediaModule(newsitem, entry, imageUrl);
		}
		
		boolean isGeotagged = newsitem.getLatitude() != null && newsitem.getLongitude() != null;
		if (isGeotagged) {
			addGeoLocationModule(newsitem, entry);
		}
		
		return entry;
	}

	private void addGeoLocationModule(Newsitem newsitem, SyndEntry entry) {
		GeoRSSModule geoRSSModule = new W3CGeoModuleImpl();
		Position position = new Position();
		position.setLatitude(newsitem.getLatitude().doubleValue());
		position.setLongitude(newsitem.getLongitude().doubleValue());		
		// TODO Is it possible to pass the address string?
		geoRSSModule.setPosition(position);		
		entry.getModules().add(geoRSSModule);
	}
	
	private void addMediaModule(Newsitem newsitem, SyndEntry entry, final String imageUrl) {
		MediaContent image = createPictureMediaContentItem(imageUrl, newsitem.getImageDescription());
		MediaEntryModuleImpl mediaModule = new MediaEntryModuleImpl();    
		MediaContent[] m= {image};
		mediaModule.setMediaContents(m);
		entry.getModules().add(mediaModule);
	}

	private MediaContent createPictureMediaContentItem(String image, String altText) {
		MediaContent mediaContent = null;
		try {
			mediaContent = createPictureMediaContentFromImage(image);
			Thumbnail thumbnail = new Thumbnail(new URL(image));

			Metadata metadata = new Metadata();
			metadata.setDescription("");
			metadata.setThumbnail(new Thumbnail[] { thumbnail });
			metadata.setDescription(altText);
			mediaContent.setMetadata(metadata);
			
		} catch (MalformedURLException e) {
		}
		return mediaContent;
	}
	
		
	private MediaContent createPictureMediaContentFromImage(String image) throws MalformedURLException {
		MediaContent mediaContent = new MediaContent(new UrlReference(image));
		mediaContent.setType("image/jpeg");
		return mediaContent;
	}

}
