package nz.gen.wellington.servlets.screenscrapers;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import nz.co.searchwellington.utils.CachingHttpFetcher;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;
import nz.gen.wellington.screenscrapers.ResolvableScreenScraper;

import org.apache.log4j.Logger;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import com.sun.syndication.feed.synd.SyndEntry;
import com.sun.syndication.feed.synd.SyndFeed;
import com.sun.syndication.feed.synd.SyndFeedImpl;
import com.sun.syndication.io.FeedException;
import com.sun.syndication.io.SyndFeedOutput;

@SuppressWarnings("serial")
@Singleton
public class ResolvingFeedController extends HttpServlet {

	Logger log = Logger.getLogger(ResolvingFeedController.class);
	   	
	ResolveableFeedDAO feedDAO;
	CachingHttpFetcher httpFetcher;
	NewsitemToSyndEntryService newsitemToSyndEntryService;
	
	@Inject
	public ResolvingFeedController(ResolveableFeedDAO feedDAO, CachingHttpFetcher httpFetcher, NewsitemToSyndEntryService newsitemToSyndEntryService) {
    	this.feedDAO = feedDAO;
    	this.httpFetcher = httpFetcher;
    	this.newsitemToSyndEntryService = newsitemToSyndEntryService;
    }
    
        
	 public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		 log.info("Handling request for path: " + request.getPathInfo());
    	
		 response.setContentType("text/xml");
		 response.setCharacterEncoding("UTF-8");
		 
	    PrintWriter writer = response.getWriter();
    	Pattern pattern = Pattern.compile("^/(.*)$");
        Matcher matcher = pattern.matcher(request.getPathInfo());
        if (matcher.matches()) {
        	final String urlStub = matcher.group(1);
    		
        	log.info("Looking for scraper for url stub: " + urlStub);        	
        	for (ResolvableScreenScraper scraper : feedDAO.getScrapers()) {        		
        		final boolean scraperUrlStubMatches = urlStub.matches(scraper.getUrlStub());
				if (scraperUrlStubMatches) {    				
    				log.info("Using scraper: " + scraper.getClass());    				
    				final String contentUrl = scraper.getPageURL(urlStub);
    				List<Newsitem> newsitems = getNewsitems(scraper, contentUrl);    			  
    				writer.print(createFeedText(newsitems, contentUrl, scraper.getName()));
    				writer.flush();
    				return;
    			}
    		}
    		log.info("No scraper found for url stub: " + urlStub);
    	}
    	
        response.setStatus(HttpServletResponse.SC_NOT_FOUND);
        return;   
    }
	 
	protected String getPageContent(String pageURL, String pageCharacterEncoding, String userAgent, Map<String, String> cookies) {
		String content = null;		
		if (pageURL != null && pageCharacterEncoding != null) {
			return httpFetcher.httpFetch(pageURL, pageCharacterEncoding, userAgent, cookies);					
		}
		return content;
	}
	
	
	protected String createFeedText(List<Newsitem> newsItems, String linkURL, String name) {		
		String feedContent = null;		
		SyndFeed feed = new SyndFeedImpl();
	
		feed.setTitle(name);
		feed.setFeedType("rss_2.0");
		feed.setLink(linkURL);
		feed.setDescription("Screen scraped news items");
		feed.setEncoding("UTF-8");
		
		List<SyndEntry> entries = new ArrayList<SyndEntry>();
		try {			
			if (newsItems.size() > 0) {
				Iterator<Newsitem> iterator = newsItems.iterator();
				while (iterator.hasNext()) {
					NewsitemImpl selectedResource = (NewsitemImpl) iterator.next();
					SyndEntry item = newsitemToSyndEntryService.makeSyndEntryFromNewsitem(selectedResource);
					entries.add(item);                                      
				}
			} else {
				log.warn("RSS Collection is empty");
			}    			
			feed.setEntries(entries);
			
		} catch (Exception e) {
			log.error(e.toString());
		}	
    
		StringWriter writer = new StringWriter();
		SyndFeedOutput output = new SyndFeedOutput();
		
		try {
			output.output(feed, writer);
			feedContent = writer.toString();			
		} catch (IOException e) {
			log.error(e.getMessage());
		} catch (FeedException e) {
			log.error(e.getMessage());
		} catch (Exception e) {
			// Catches an illegal data error inside JDOM.
			log.error(e.toString());          
		}
		
		return feedContent;			
	}
	
	private List<Newsitem> getNewsitems(ResolvableScreenScraper scraper, String contentUrl) {
		List <Newsitem> newsitems = new ArrayList<Newsitem>();
		
		final String content = getPageContent(contentUrl, scraper.getCharacterEncoding(), scraper.getUserAgent(), scraper.getCookies());        
		if (content != null) {
			try {
				newsitems = scraper.parseContent(content);
			} catch (Exception e) {
				log.error("Scraper throw an exception while parsing", e);
			}
		} else {            
			log.warn("Page content could not be loaded from url: " + contentUrl);
		}
		
		return newsitems;
	}
	
}
