package nz.gen.wellington.screenscrapers.twickenham;

import java.util.Date;
import java.util.List;

import nz.co.searchwellington.utils.CachingHttpFetcher;
import nz.gen.wellington.screenscrapers.Base;
import nz.gen.wellington.screenscrapers.Newsitem;
import nz.gen.wellington.screenscrapers.NewsitemImpl;

public class LBRUTPlanningApplicationsScraperTest extends Base {
	
	private LBRUTPlanningApplicationsScraper scraper;
	private CachingHttpFetcher httpFetcher;

	public void setUp() throws Exception {
		super.setUp();
		scraper = new LBRUTPlanningApplicationsScraper(httpFetcher);
	}
	
	public void testUrlShouldQueryForLastWeeksDateRange() throws Exception {
		final String pageURL = scraper.getPageURL();
		
		assertEquals("http://www2.richmond.gov.uk/PlanData2/planning_summary.aspx?strWeekListType=SRCH&strDecFrom=&strDecTo=&strRecFrom=18-Sep-2011&strRecTo=25-Sep-2011&strWard=ALL&strAppTyp=ALL&strWardTxt=All%20Wards&strAppTypTxt=ALL%20-%20all%20applications&strAppStat=ALL&strAppStatTxt=All%20Applications&strStreet=ALL&strStreetTxt=All%20Streets&strLimit=50&strOrder=REC_DEC&strOrderTxt=Most%20recently%20received%20first", pageURL);
		assertTrue(pageURL.contains("strRecFrom=18-Sep-2011"));
		assertTrue(pageURL.contains("strRecTo=25-Sep-2011"));
	}

	public void testCanParseResultsScreen() throws Exception {		
		StringBuffer content = loadContent("planning_summary.html");
		
		List<Newsitem> extractedItems = scraper.parseContent(content.toString());
		assertEquals(15, extractedItems.size());
			
		Newsitem first = extractedItems.get(0);
		assertEquals("1 And 2 The Grove And Grove Cottage, Lower Teddington Road, Kingston Upon Thames", first.getTitle());
		assertEquals("http://www2.richmond.gov.uk/PlanData2/Planning_CaseNo.aspx?strCASENO=11/T0669/TPO", first.getUrl());
	}
	
	public void testCanExtractApplicationDateAndLocationFromPlanningApplicationDetailsPage() throws Exception {
		StringBuffer content = loadContent("planning_case.html");
        Date applicationDate = scraper.getApplicationDateFromDetailsPage(content.toString());
		assertEquals("22 Sep 2011", df.format(applicationDate.getTime()));
	}

	public void testCanExtractLocationFromMapLinkIfPresent() throws Exception {
		StringBuffer content = loadContent("planning_case.html");
		Newsitem newsitem = new NewsitemImpl();
		
		scraper.setApplicationDateLocation(content.toString(), newsitem);
		
		assertEquals("51.4556421732255", newsitem.getLatitude().toString());
		assertEquals("-0.298601047773077", newsitem.getLongitude().toString());
	}
}
