package nz.gen.wellington.screenscrapers;



import java.io.File;
import java.util.List;

import nz.gen.wellington.screenscrapers.auckland.ArcNewsScraper;
import nz.gen.wellington.screenscrapers.auckland.ArtaScraper;
import nz.gen.wellington.screenscrapers.auckland.AruNewsScraper;
import nz.gen.wellington.screenscrapers.auckland.AucklandAirportScraper;
import nz.gen.wellington.screenscrapers.auckland.AucklandHealthBoardScraper;
import nz.gen.wellington.screenscrapers.auckland.AucklandUniversityScreenScraper;
import nz.gen.wellington.screenscrapers.auckland.AucklandZooNewsScraper;
import nz.gen.wellington.screenscrapers.auckland.MAXXScraper;
import nz.gen.wellington.screenscrapers.auckland.ManukauCityCouncilScraper;
import nz.gen.wellington.screenscrapers.auckland.NorthShoreScraper;
import nz.gen.wellington.screenscrapers.wellington.BypassScraper;
import nz.gen.wellington.screenscrapers.wellington.NorthernCourierScraper;
import nz.gen.wellington.screenscrapers.wellington.Base;
import nz.gen.wellington.screenscrapers.wimbledon.SuttonScraper;




public class ScreenScraperTests extends Base {

    
  
	
	
	
	
	public void testArtaScreenScraper() throws Exception {
		
		ScreenScraper arta = new ArtaScraper();	
		File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/arta_news.htm");					
		StringBuffer content = loadContent(contentFile);
								
		List extractedItems = arta.parseContent(content.toString());
		
		// There are 63 items on this page, but the scraper should limit it to 10
		assertEquals(10, extractedItems.size());						
	}
	
	

	
	
	
	
	
	

	public void testArcScreenScraper() throws Exception {
			
		ScreenScraper arc = new ArcNewsScraper();					
		File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/arc_news.html");			
		StringBuffer content = loadContent(contentFile);
		List extractedItems = arc.parseContent(content.toString());
		
		assertEquals(6, extractedItems.size());
		
		// Check for whitespace trimming.
		Newsitem andItem = (Newsitem) extractedItems.get(0);		
		assertEquals("ARC adopts 10-year plan with 4.9% average rate increase", andItem.getTitle());		
	}
	
	
	
	
	public void testAucklandZooScreenScraper() throws Exception {

        ScreenScraper aru = new AucklandZooNewsScraper();
        File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/auckland_zoo_news.php");
        StringBuffer content = loadContent(contentFile);
        List extractedItems = aru.parseContent(content.toString());

        assertEquals(5, extractedItems.size());

        Newsitem fouthItem = (Newsitem) extractedItems.get(3);
        assertEquals("Auckland Zoo tiger Nisha dies", fouthItem.getTitle());
        assertEquals("http://www.aucklandzoo.co.nz/aucklandzoo/news_item.php?id=1147415699&amp;archiveYear=&amp;page=1", fouthItem.getUrl());
        assertEquals("12 May 2006", df.format(fouthItem.getDate().getTime()));
        assertEquals("One of Auckland Zoo's most loved animals, Sumatran tiger Nisha, died suddenly today.", fouthItem.getDescription());
    }
	
	
	
	





	public void testAruScreenScraper() throws Exception {
			
		ScreenScraper aru = new AruNewsScraper();
		File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/aru_news.htm");			
		StringBuffer content = loadContent(contentFile);
		List extractedItems = aru.parseContent(content.toString());
			
		assertEquals(4, extractedItems.size());		
		Newsitem firstItem = (Newsitem) extractedItems.get(0);		
		assertEquals("Club Rugby Review - Round 2", firstItem.getTitle());
        assertEquals("http://www.aucklandrugby.co.nz/club/news/article.html?newsid=7786926", firstItem.getUrl());        
	}
	
	
	
	public void testAucklandUniversityScreenScraper() throws Exception {
		
		ScreenScraper au = new AucklandUniversityScreenScraper();		
		File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/aucklanduni.cfm");			
		StringBuffer content = loadContent(contentFile);
		List extractedItems = au.parseContent(content.toString());
		
		// There are 10 items on this page.
		assertEquals(10, extractedItems.size());

		Newsitem first = (Newsitem) extractedItems.get(0);
		assertEquals("Cricket bowling feet kept comfy through science", first.getTitle());
        assertEquals("http://www.auckland.ac.nz/uoa/about/news/articles/2007/04/cricket.cfm", first.getUrl());
		assertEquals("26 Apr 2007", df.format(first.getDate().getTime()));
        assertEquals("New Zealand cricket players may be being helped in the World Cup by an unlikely source - scientists.", first.getDescription());	
	}
	
	
    
   
    
    
    
    
  
    
    
    
  
    
    
    public void testADHBScraper() throws Exception {
        
        ScreenScraper adhb = new AucklandHealthBoardScraper();

        File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/adhb-media-releases.htm");          
        StringBuffer content = loadContent(contentFile);
        
        List extractedItems = adhb.parseContent(content.toString());        
        assertEquals(11, extractedItems.size());
        
        Newsitem first = (Newsitem) extractedItems.get(0);

        assertEquals("9 Aug 2006", df.format(first.getDate().getTime()));
        assertEquals("http://www.adhb.govt.nz/news/media-releases/060809.htm", first.getUrl());
        assertEquals("Court action after failed bid to win contract", first.getTitle());        
    }
    
 
    
    
    
    
    
 public void testNorthShoreScraper() throws Exception {
        
        ScreenScraper ns = new NorthShoreScraper();
        File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/northshore.htm");          
        StringBuffer content = loadContent(contentFile);        
        List extractedItems = ns.parseContent(content.toString());        

        assertEquals(11, extractedItems.size());
              
        Newsitem first = (Newsitem) extractedItems.get(0);
        assertEquals("Inaugural event wins award", first.getTitle());        
        assertEquals("http://www.northshorecity.govt.nz/your_council/news_releases/Releases-2006/August/Inaugural-event-wins-award.htm", first.getUrl());     
        assertEquals("17 Aug 2006", df.format(first.getDate().getTime()));        
 }
    
   
 
 
 public void testAucklandAirportScraper() throws Exception {
     
     ScreenScraper ns = new AucklandAirportScraper();
     File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/auckland-airport.html");          
     StringBuffer content = loadContent(contentFile);     
     List extractedItems = ns.parseContent(content.toString());        
     assertEquals(3, extractedItems.size());
        
     Newsitem first = (Newsitem) extractedItems.get(0);
     assertEquals("Update on duty free purchases for Qantas passengers travelling to the US from Auckand Airport", first.getTitle());   
     assertEquals("http://www.auckland-airport.co.nz/NewsHistory/press_releases.php?rid=150", first.getUrl());
     assertTrue(first.getDescription().startsWith("The Aviation Security Service and Qantas have advised Auckland Airport"));
     assertEquals("18 Aug 2006", df.format(first.getDate().getTime()));         
 }
 
 
 
 public void testSuttonScraper() throws Exception {
   
     ScreenScraper sutton = new SuttonScraper();
     File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/sutton-news.html");          
     StringBuffer content = loadContent(contentFile);
     
     List extractedItems = sutton.parseContent(content.toString());        
     assertEquals(8, extractedItems.size());
     
     Newsitem first = (Newsitem) extractedItems.get(0);
     assertEquals("Sun and sand bring seaside fun to Sutton", first.getTitle());   
     assertEquals("http://www.sutton.gov.uk/news/latest/pr955.htm", first.getUrl());
     assertEquals("16 Aug 2006", df.format(first.getDate().getTime()));     
     assertTrue(first.getDescription().startsWith("Families in Sutton enjoyed a taste of the seaside"));          
 }
 
 
 
 
 
 public void testManukauScraper() throws Exception {
     
     ScreenScraper adhb = new ManukauCityCouncilScraper();

     File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/manukau-news.htm");          
     StringBuffer content = loadContent(contentFile);
     
     List extractedItems = adhb.parseContent(content.toString());        
     assertEquals(13, extractedItems.size());
     
     Newsitem first = (Newsitem) extractedItems.get(0);
     assertEquals("Mangere ward councillor by-election - information sheet", first.getTitle());        
     assertEquals("http://www.manukau.govt.nz/Latest/2006/August/By-election.htm", first.getUrl());
     assertEquals("17 Aug 2006", df.format(first.getDate().getTime()));
     assertTrue(first.getDescription().startsWith("A by-election is an election that takes place during the term between official triennial election periods."));
     
     Newsitem third = (Newsitem) extractedItems.get(2); 
     assertEquals("17 Aug 2006", df.format(third.getDate().getTime()));     
 }
 
 

 
 
 public void testMAXXScraper() throws Exception {
        ScreenScraper adhb = new MAXXScraper();

        File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/maxx_media_releases.htm");
        StringBuffer content = loadContent(contentFile);

        List extractedItems = adhb.parseContent(content.toString());
        assertEquals(10, extractedItems.size());

        Newsitem first = (Newsitem) extractedItems.get(0);
        assertEquals("Railway station gets the green light at Sylvia Park", first.getTitle());
        assertEquals("23 Aug 2006", df.format(first.getDate().getTime()));        
        assertTrue(first.getDescription().startsWith("Kiwi Income Property Trust advised today that construction of the new railway station that will service Sylvia Park"));

        Newsitem second = (Newsitem) extractedItems.get(1);
        assertEquals("Special train services provided for Maori Queen's funeral", second.getTitle());
        assertEquals("http://www.rideline.co.nz/media_releases.html?releaseid=222c6428-f206-b719-3f17-66b66b3d6b01", second.getUrl());
     

    }
    
    
 
 public void testNorthenCourierFeatures() throws Exception {
     ScreenScraper nc = new NorthernCourierScraper();
     File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/northerncourier.htm");
     StringBuffer content = loadContent(contentFile);
     List extractedItems = nc.parseContent(content.toString());
	     
     assertEquals(4, extractedItems.size());	 
     Newsitem first = (Newsitem) extractedItems.get(0);
     Newsitem second = (Newsitem) extractedItems.get(1);
     Newsitem third  = (Newsitem) extractedItems.get(2);
   
     assertEquals("Changes To Ohariu-Belmont Roll", first.getTitle());
     assertEquals("http://www.localmedia.co.nz/northerncourier/stories/nc221106/p8-NC221106Generals-Electoral.html", first.getUrl());
     assertEquals("22 Nov 2006", df.format(first.getDate().getTime()));

     assertEquals("Tawa College Cleans Up Sporting Awards", second.getTitle());
     assertEquals("http://www.localmedia.co.nz/northerncourier/stories/nc221106/p7-NC221106Generals-CollegeSport.html", second.getUrl());
     assertEquals("22 Nov 2006", df.format(second.getDate().getTime()));
 
     assertEquals("Art Exclusive", third.getTitle());
     assertEquals("http://www.localmedia.co.nz/northerncourier/stories/nc221106/p3-NC221106Generals-Pataka.html", third.getUrl());
     assertEquals("22 Nov 2006", df.format(third.getDate().getTime()));
 }
 
 
 
 
 
 
 
 
 
 public void testBypassScraper() throws Exception {
	    
     ScreenScraper wrfu = new BypassScraper();
     File contentFile = new File("test/java/nz/gen/wellington/screenscrapers/bypass_news.htm");
     StringBuffer content = loadContent(contentFile);
	
     List extractedItems = wrfu.parseContent(content.toString());
     assertEquals(22, extractedItems.size());
  
     Newsitem first = (Newsitem) extractedItems.get(0);
     assertEquals("http://www.transit.govt.nz/projects/wicb/news/022.jsp", first.getUrl());
     assertEquals("1 Dec 2006", df.format(first.getDate().getTime()));
     assertEquals(first.getTitle(), "Wellington Inner City Bypass: Willis Street works");
     assertTrue(first.getDescription().startsWith("As part of the Inner City Bypass, work has commenced on Willis Street"));
     
     assertFalse(first.getDescription().endsWith("More")); 
 }
 
 

}